@@ -70,7 +70,7 @@ class Exceptions:
 
 class DataPipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html)
     """
 
@@ -86,13 +86,13 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        parameterValues: Sequence["ParameterValueTypeDef"] = None,
-        startTimestamp: Union[datetime, str] = None
+        parameterValues: Sequence["ParameterValueTypeDef"] = ...,
+        startTimestamp: Union[datetime, str] = ...
     ) -> Dict[str, Any]:
         """
         Validates the specified pipeline and starts processing pipeline tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#activate_pipeline)
         """
 
@@ -100,7 +100,7 @@ class DataPipelineClient(BaseClient):
         """
         Adds or modifies tags for the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#add_tags)
         """
 
@@ -108,7 +108,7 @@ class DataPipelineClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#can_paginate)
         """
 
@@ -117,21 +117,21 @@ class DataPipelineClient(BaseClient):
         *,
         name: str,
         uniqueId: str,
-        description: str = None,
-        tags: Sequence["TagTypeDef"] = None
+        description: str = ...,
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a new, empty pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#create_pipeline)
         """
 
-    def deactivate_pipeline(self, *, pipelineId: str, cancelActive: bool = None) -> Dict[str, Any]:
+    def deactivate_pipeline(self, *, pipelineId: str, cancelActive: bool = ...) -> Dict[str, Any]:
         """
         Deactivates the specified running pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#deactivate_pipeline)
         """
 
@@ -139,7 +139,7 @@ class DataPipelineClient(BaseClient):
         """
         Deletes a pipeline, its pipeline definition, and its run history.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#delete_pipeline)
         """
 
@@ -148,13 +148,13 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         objectIds: Sequence[str],
-        evaluateExpressions: bool = None,
-        marker: str = None
+        evaluateExpressions: bool = ...,
+        marker: str = ...
     ) -> DescribeObjectsOutputTypeDef:
         """
         Gets the object definitions for a set of objects associated with the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_objects)
         """
 
@@ -162,7 +162,7 @@ class DataPipelineClient(BaseClient):
         """
         Retrieves metadata about one or more pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_pipelines)
         """
 
@@ -173,40 +173,40 @@ class DataPipelineClient(BaseClient):
         Task runners call `EvaluateExpression` to evaluate a string in the context of
         the specified object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#evaluate_expression)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#generate_presigned_url)
         """
 
     def get_pipeline_definition(
-        self, *, pipelineId: str, version: str = None
+        self, *, pipelineId: str, version: str = ...
     ) -> GetPipelineDefinitionOutputTypeDef:
         """
         Gets the definition of the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#get_pipeline_definition)
         """
 
-    def list_pipelines(self, *, marker: str = None) -> ListPipelinesOutputTypeDef:
+    def list_pipelines(self, *, marker: str = ...) -> ListPipelinesOutputTypeDef:
         """
         Lists the pipeline identifiers for all active pipelines that you have permission
         to access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#list_pipelines)
         """
 
@@ -214,14 +214,14 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         workerGroup: str,
-        hostname: str = None,
-        instanceIdentity: "InstanceIdentityTypeDef" = None
+        hostname: str = ...,
+        instanceIdentity: "InstanceIdentityTypeDef" = ...
     ) -> PollForTaskOutputTypeDef:
         """
         Task runners call `PollForTask` to receive a task to perform from AWS Data
         Pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#poll_for_task)
         """
 
@@ -230,13 +230,13 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         pipelineObjects: Sequence["PipelineObjectTypeDef"],
-        parameterObjects: Sequence["ParameterObjectTypeDef"] = None,
-        parameterValues: Sequence["ParameterValueTypeDef"] = None
+        parameterObjects: Sequence["ParameterObjectTypeDef"] = ...,
+        parameterValues: Sequence["ParameterValueTypeDef"] = ...
     ) -> PutPipelineDefinitionOutputTypeDef:
         """
         Adds tasks, schedules, and preconditions to the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#put_pipeline_definition)
         """
 
@@ -245,15 +245,15 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         sphere: str,
-        query: "QueryTypeDef" = None,
-        marker: str = None,
-        limit: int = None
+        query: "QueryTypeDef" = ...,
+        marker: str = ...,
+        limit: int = ...
     ) -> QueryObjectsOutputTypeDef:
         """
         Queries the specified pipeline for the names of objects that match the specified
         set of conditions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#query_objects)
         """
 
@@ -261,29 +261,29 @@ class DataPipelineClient(BaseClient):
         """
         Removes existing tags from the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#remove_tags)
         """
 
     def report_task_progress(
-        self, *, taskId: str, fields: Sequence["FieldTypeDef"] = None
+        self, *, taskId: str, fields: Sequence["FieldTypeDef"] = ...
     ) -> ReportTaskProgressOutputTypeDef:
         """
         Task runners call `ReportTaskProgress` when assigned a task to acknowledge that
         it has the task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_progress)
         """
 
     def report_task_runner_heartbeat(
-        self, *, taskrunnerId: str, workerGroup: str = None, hostname: str = None
+        self, *, taskrunnerId: str, workerGroup: str = ..., hostname: str = ...
     ) -> ReportTaskRunnerHeartbeatOutputTypeDef:
         """
         Task runners call `ReportTaskRunnerHeartbeat` every 15 minutes to indicate that
         they are operational.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_runner_heartbeat)
         """
 
@@ -292,7 +292,7 @@ class DataPipelineClient(BaseClient):
         Requests that the status of the specified physical or logical pipeline objects
         be updated in the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.set_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.set_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_status)
         """
 
@@ -301,15 +301,15 @@ class DataPipelineClient(BaseClient):
         *,
         taskId: str,
         taskStatus: TaskStatusType,
-        errorId: str = None,
-        errorMessage: str = None,
-        errorStackTrace: str = None
+        errorId: str = ...,
+        errorMessage: str = ...,
+        errorStackTrace: str = ...
     ) -> Dict[str, Any]:
         """
         Task runners call `SetTaskStatus` to notify AWS Data Pipeline that a task is
         completed and provide information about the final status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_task_status)
         """
 
@@ -318,14 +318,14 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         pipelineObjects: Sequence["PipelineObjectTypeDef"],
-        parameterObjects: Sequence["ParameterObjectTypeDef"] = None,
-        parameterValues: Sequence["ParameterValueTypeDef"] = None
+        parameterObjects: Sequence["ParameterObjectTypeDef"] = ...,
+        parameterValues: Sequence["ParameterValueTypeDef"] = ...
     ) -> ValidatePipelineDefinitionOutputTypeDef:
         """
         Validates the specified pipeline definition to ensure that it is well formed and
         can be run without error.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#validate_pipeline_definition)
         """
 
@@ -334,20 +334,20 @@ class DataPipelineClient(BaseClient):
         self, operation_name: Literal["describe_objects"]
     ) -> DescribeObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#describeobjectspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_objects"]) -> QueryObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#queryobjectspaginator)
         """
